==> hono-example-0.5.jar: META-INF/NOTICE.md <==
This content is produced and maintained by the Eclipse Hono project.

* Project home: https://www.eclipse.org/hono

# Declared Project Licenses

This program and the accompanying materials are made available under the terms
of the Eclipse Public License 1.0 which is available at https://www.eclipse.org/legal/epl-v10.html.

# Source Code

* https://github.com/eclipse/hono

# Copyright Holders

* Copyright 2016-2017 Bosch Software Innovations GmbH
* Copyright 2016-2017 Red Hat

# Third-party Content

### AOP Alliance classes 1.0

This product includes software developed by the [AOP Alliance](http://aopalliance.sourceforge.net).

The *AOP Alliance classes* are *Public Domain*.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=aopalliance/aopalliance/1.0/aopalliance-1.0-sources.jar).

### Apache Commons Logging 1.2

This product includes software developed by the [Apache Software Foundation](http://www.apache.org/).

Your use of *Apache Commons Logging* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=commons-logging/commons-logging/1.2/commons-logging-1.2-sources.jar).

### Jackson 2.9.0

This product includes software developed by [FasterXML, LLC](http://fasterxml.com/).

Your use of *Jackson* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"com.fasterxml.jackson.core"%20AND%20v:"2.9.0"%20AND%20l:"sources").

### JCL-over-SLF4J 1.7.24

This product includes software developed by the [Apache Software Foundation](http://www.apache.org/).

Your use of *JCL-over-SLF4J* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/slf4j/jcl-over-slf4j/1.7.24/jcl-over-slf4j-1.7.24-sources.jar).

### JUL-to-SLF4J 1.7.24

This product includes software developed by [Quality Open Software](http://www.qos.ch/).

Your use of *JUL-to-SLF4J* is subject to the terms and conditions of the MIT License.
A copy of the license is contained in the file [LICENSE.JUL-to-SLF4J.txt](LICENSE.JUL-to-SLF4J.txt).

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/slf4j/jul-to-slf4j/1.7.24/jul-to-slf4j-1.7.24-sources.jar).

### JJWT 0.7.0

This product includes software developed by [Stormpath](https://java.jsonwebtoken.io/).

Your use of *JJWT* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/jsonwebtoken/jjwt/0.7.0/jjwt-0.7.0-sources.jar).

### LOG4J-over-SLF4J 1.7.24

This product includes software developed by the [Apache Software Foundation](http://www.apache.org/).

Your use of *LOG4J-over-SLF4J* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/slf4j/log4j-over-slf4j/1.7.24/log4j-over-slf4j-1.7.24-sources.jar).

### Logback 1.2.3

This product includes software developed by [Quality Open Software](http://www.qos.ch/).

Your use of *Logback* is subject to the terms and conditions of the Eclipse Public License 1.0.
A copy of the license is contained in the file [LICENSE](LICENSE) and is also available at https://eclipse.org/legal/epl-v10.html.

The source code is available from [Maven Central](http://search.maven.org/#search%7Cga%7C1%7Cg%3A%22ch.qos.logback%22%20AND%20v%3A%221.2.3%22).

### Metrics 3.2.2

This product includes software developed by the [Metrics project](http://metrics.dropwizard.io/).

Your use of *Metrics* is subject to the terms and conditions of the Apache Software License 2.0 and others
as indicated by the file [NOTICE.Metrics.txt](NOTICE.Metrics.txt). This file contains links to the licenses
whose terms and conditions apply.

A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"io.dropwizard.metrics"%20AND%20v:"3.2.2"%20AND%20l:"sources").

### Netty 4.1.15.Final

This product includes software developed by [The Netty project](http://netty.io/).

Your use of *Netty* is subject to the terms and conditions of the Apache Software License 2.0 and others
as indicated by the file [NOTICE.Netty.txt](NOTICE.Netty.txt). This file contains links to the licenses
whose terms and conditions apply.

A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"io.netty"%20AND%20v:"4.1.15.Final"%20AND%20l:"sources").

### Proton-j 0.22.0

This product includes software developed by the [Apache Software Foundation](http://www.apache.org/).

Your use of *Proton-j* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/apache/qpid/proton-j/0.22.0/proton-j-0.22.0-sources.jar).

### SLF4J API 1.7.24

This product includes software developed by [Quality Open Software](http://www.qos.ch/).

Your use of *SLF4J API* is subject to the terms and conditions of the MIT License.
A copy of the license is contained in the file [LICENSE.slf4j.txt](LICENSE.slf4j.txt)
and is also available at http://slf4j.org/license.html

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/slf4j/slf4j-api/1.7.24/slf4j-api-1.7.24-sources.jar).

### SnakeYAML 1.17

This product includes software developed by the [SnakeYAML project](http://www.snakeyaml.org).

Your use of *SnakeYAML* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/yaml/snakeyaml/1.17/snakeyaml-1.17-sources.jar).

### Spring Framework 4.3.12.RELEASE

This product includes software developed by the [Spring project](http://spring.io) and others.

Your use of the *Spring Framework* is subject to the terms and conditions of the Apache Software License 2.0
and others as indicated by [NOTICE.Spring.txt](NOTICE.Spring.txt).
A copy of the licenses is contained in the file [LICENSE.Spring.txt](LICENSE.Spring.txt).

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"org.springframework"%20AND%20v:"4.3.12.RELEASE"%20AND%20l:"sources").

### Spring Boot 1.5.8.RELEASE

This product includes software developed by the [Spring projects](http://spring.io).

Your use of *Spring Boot* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"org.springframework.boot"%20AND%20v:"1.5.8.RELEASE"%20AND%20l:"sources").

### vert.x Auth Common 3.5.0

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Auth Common* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-auth-common/3.5.0/vertx-auth-common-3.5.0-sources.jar).

### vert.x Dropwizard Metrics 3.5.0

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Dropwizard Metrics* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-dropwizard-metrics/3.5.0/vertx-dropwizard-metrics-3.5.0-sources.jar).

### vert.x Health Check 3.5.0

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Health Check* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-health-check/3.5.0/vertx-health-check-3.5.0-sources.jar).

### vert.x MQTT Server 3.5.0

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x MQTT Server* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-mqtt-server/3.5.0/vertx-mqtt-server-3.5.0-sources.jar).

### vert.x Proton 3.5.0

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Proton* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-proton/3.5.0/vertx-proton-3.5.0-sources.jar).

### vert.x Web 3.5.0

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Web* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-web/3.5.0/vertx-web-3.5.0-sources.jar).

# Trademarks

* Eclipse Hono and the Eclipse Hono project logo are trademarks of the Eclipse Foundation.
* Eclipse and the Eclipse logo are registered trademarks of The Eclipse Foundation.
* Java and all Java-based trademarks are trademarks of Oracle Corporation in the United States, other countries, or both.

# Cryptography

Content may contain encryption software. The country in which you are currently
may have restrictions on the import, possession, and use, and/or re-export to
another country, of encryption software. BEFORE using any encryption software,
please check the country's laws, regulations and policies concerning the import,
possession, or use, and re-export of encryption software, to see if this is
permitted.

==> hono-example-0.6.jar: META-INF/NOTICE.md <==
This content is produced and maintained by the Eclipse Hono project.

* Project home: https://www.eclipse.org/hono

# Declared Project Licenses

This program and the accompanying materials are made available under the terms
of the Eclipse Public License 1.0 which is available at https://www.eclipse.org/legal/epl-v10.html.

# Source Code

* https://github.com/eclipse/hono

# Copyright Holders

* Copyright 2016-2018 Bosch Software Innovations GmbH
* Copyright 2016-2018 Red Hat, Inc.
* Copyright 2017 Francois Travais
* Copyright 2018 Alfusainey Jallow

# Third-party Content

### AOP Alliance classes 1.0

This product includes software developed by the [AOP Alliance](http://aopalliance.sourceforge.net).

The *AOP Alliance classes* are *Public Domain*.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=aopalliance/aopalliance/1.0/aopalliance-1.0-sources.jar).

### Apache Commons Logging 1.2

This product includes software developed by the [Apache Software Foundation](http://www.apache.org/).

Your use of *Apache Commons Logging* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=commons-logging/commons-logging/1.2/commons-logging-1.2-sources.jar).

### Google Guava 19.0

This product includes software developed by the [Guava project](https://github.com/google/guava).

Your use of *Guava* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=com/google/guava/guava/19.0/guava-19.0-sources.jar).

### Jackson 2.9.0

This product includes software developed by [FasterXML, LLC](http://fasterxml.com/).

Your use of *Jackson* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"com.fasterxml.jackson.core"%20AND%20v:"2.9.0"%20AND%20l:"sources").

### JCL-over-SLF4J 1.7.24

This product includes software developed by the [Apache Software Foundation](http://www.apache.org/).

Your use of *JCL-over-SLF4J* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/slf4j/jcl-over-slf4j/1.7.24/jcl-over-slf4j-1.7.24-sources.jar).

### JUL-to-SLF4J 1.7.24

This product includes software developed by [Quality Open Software](http://www.qos.ch/).

Your use of *JUL-to-SLF4J* is subject to the terms and conditions of the MIT License.
A copy of the license is contained in the file [LICENSE.JUL-to-SLF4J.txt](LICENSE.JUL-to-SLF4J.txt).

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/slf4j/jul-to-slf4j/1.7.24/jul-to-slf4j-1.7.24-sources.jar).

### JJWT 0.7.0

This product includes software developed by [Stormpath](https://java.jsonwebtoken.io/).

Your use of *JJWT* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/jsonwebtoken/jjwt/0.7.0/jjwt-0.7.0-sources.jar).

### LOG4J-over-SLF4J 1.7.24

This product includes software developed by the [Apache Software Foundation](http://www.apache.org/).

Your use of *LOG4J-over-SLF4J* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the license is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and is also available at
http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/slf4j/log4j-over-slf4j/1.7.24/log4j-over-slf4j-1.7.24-sources.jar).

### Logback 1.2.3

This product includes software developed by [Quality Open Software](http://www.qos.ch/).

Your use of *Logback* is subject to the terms and conditions of the Eclipse Public License 1.0.
A copy of the license is contained in the file [LICENSE](LICENSE) and is also available at https://eclipse.org/legal/epl-v10.html.

The source code is available from [Maven Central](http://search.maven.org/#search%7Cga%7C1%7Cg%3A%22ch.qos.logback%22%20AND%20v%3A%221.2.3%22).

### Metrics 3.2.2

This product includes software developed by the [Metrics project](http://metrics.dropwizard.io/).

Your use of *Metrics* is subject to the terms and conditions of the Apache Software License 2.0 and others
as indicated by the file [NOTICE.Metrics.txt](NOTICE.Metrics.txt). This file contains links to the licenses
whose terms and conditions apply.

A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"io.dropwizard.metrics"%20AND%20v:"3.2.2"%20AND%20l:"sources").

### Netty 4.1.15.Final

This product includes software developed by [The Netty project](http://netty.io/).

Your use of *Netty* is subject to the terms and conditions of the Apache Software License 2.0 and others
as indicated by the file [NOTICE.Netty.txt](NOTICE.Netty.txt). This file contains links to the licenses
whose terms and conditions apply.

A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"io.netty"%20AND%20v:"4.1.15.Final"%20AND%20l:"sources").

### Proton-j 0.25.0

This product includes software developed by the [Apache Software Foundation](http://www.apache.org/).

Your use of *Proton-j* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/apache/qpid/proton-j/0.25.0/proton-j-0.25.0-sources.jar).

### SLF4J API 1.7.24

This product includes software developed by [Quality Open Software](http://www.qos.ch/).

Your use of *SLF4J API* is subject to the terms and conditions of the MIT License.
A copy of the license is contained in the file [LICENSE.slf4j.txt](LICENSE.slf4j.txt)
and is also available at http://slf4j.org/license.html

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/slf4j/slf4j-api/1.7.24/slf4j-api-1.7.24-sources.jar).

### SnakeYAML 1.17

This product includes software developed by the [SnakeYAML project](http://www.snakeyaml.org).

Your use of *SnakeYAML* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=org/yaml/snakeyaml/1.17/snakeyaml-1.17-sources.jar).

### Spring Framework 4.3.12.RELEASE

This product includes software developed by the [Spring project](http://spring.io) and others.

Your use of the *Spring Framework* is subject to the terms and conditions of the Apache Software License 2.0
and others as indicated by [NOTICE.Spring.txt](NOTICE.Spring.txt).
A copy of the licenses is contained in the file [LICENSE.Spring.txt](LICENSE.Spring.txt).

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"org.springframework"%20AND%20v:"4.3.12.RELEASE"%20AND%20l:"sources").

### Spring Boot 1.5.8.RELEASE

This product includes software developed by the [Spring project](http://spring.io).

Your use of *Spring Boot* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/#search|ga|1|g:"org.springframework.boot"%20AND%20v:"1.5.8.RELEASE"%20AND%20l:"sources").

### vert.x Auth Common 3.5.1

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Auth Common* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-auth-common/3.5.1/vertx-auth-common-3.5.1-sources.jar).

### vert.x Bridge Common 3.5.1

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Bridge Common* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-bridge-common/3.5.1/vertx-bridge-common-3.5.1-sources.jar).

### vert.x Dropwizard Metrics 3.5.1

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Dropwizard Metrics* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-dropwizard-metrics/3.5.1/vertx-dropwizard-metrics-3.5.1-sources.jar).

### vert.x Health Check 3.5.1

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Health Check* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-health-check/3.5.1/vertx-health-check-3.5.1-sources.jar).

### vert.x MQTT 3.5.1

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x MQTT* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-mqtt/3.5.1/vertx-mqtt-3.5.1-sources.jar).

### vert.x Proton 3.5.1

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Proton* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-proton/3.5.1/vertx-proton-3.5.1-sources.jar).

### vert.x Web 3.5.1

This product includes software developed by the [vert.x project](http://vertx.io).

Your use of *vert.x Web* is subject to the terms and conditions of the Apache Software License 2.0.
A copy of the Apache Software License 2.0 is contained in the file [LICENSE-2.0.txt](LICENSE-2.0.txt) and
is also available at http://www.apache.org/licenses/LICENSE-2.0.html.

The source code is available from [Maven Central](http://search.maven.org/remotecontent?filepath=io/vertx/vertx-web/3.5.1/vertx-web-3.5.1-sources.jar).

# Trademarks

* Eclipse Hono and the Eclipse Hono project logo are trademarks of the Eclipse Foundation.
* Eclipse and the Eclipse logo are registered trademarks of The Eclipse Foundation.
* Java and all Java-based trademarks are trademarks of Oracle Corporation in the United States, other countries, or both.

# Cryptography

Content may contain encryption software. The country in which you are currently
may have restrictions on the import, possession, and use, and/or re-export to
another country, of encryption software. BEFORE using any encryption software,
please check the country's laws, regulations and policies concerning the import,
possession, or use, and re-export of encryption software, to see if this is
permitted.
